==> jonas-JONAS_4_6_4.tar.gz: jonas-JONAS_4_6_4/jonas/src/org/objectweb/jonas_lib/version/Version.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999-2004 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_lib.version;

/**
 * Information about the current version of JOnAS.
 *
 * @author jonas-team
 */
public class Version {

    /**
     * Version number of JOnAS
     */
    public static final String NUMBER = "4.6.4";

    /**
     *  JOnAS Vendor
     */
    public static final String VENDOR = "ObjectWeb";

    /**
     * Private constructor (utility class)
     */
    private Version() { }

    /**
     * Main method of this class which display the version number
     *
     * @param args the arguments for this program
     */
    public static void main(String[] args) {
        System.out.println("JOnAS version: " + NUMBER);
        System.out.println("JOnAS vendor: " + VENDOR);
    }

}

==> jonas-JONAS_4_10_6.tar.gz: jonas-JONAS_4_10_6/jonas/src/org/objectweb/jonas_lib/version/Version.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999-2004 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_lib.version;

/**
 * Information about the current version of JOnAS.
 *
 * @author jonas-team
 */
public class Version {

    /**
     * Version number of JOnAS.
     */
    public static final String NUMBER = "4.10.6";

    /**
     *  JOnAS Vendor.
     */
    public static final String VENDOR = "OW2";

    /**
     * Private constructor (utility class).
     */ 
    private Version() { }

    /**
     * Main method of this class which display the version number.
     * @param args the arguments for this program
     */
    public static void main(String[] args) {
        System.out.println("JOnAS version: " + getNumber());
        System.out.println("JOnAS vendor: " + VENDOR);
    }

    /**
     * @return Returns the JOnAS Version Number.
     */
    public static String getNumber() {
        return NUMBER;
    }

}
